# -*- coding: utf-8 -*-

from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.core.admin.options import ExtendibleModelAdmin
from jmb.core.forms.models import AdminModelForm
from jmb.slider.models import Slider, Picture

from image_cropping import ImageCroppingMixin
from image_cropping import ImageCropWidget


class PictureInline(ImageCroppingMixin, admin.StackedInline):
    model = Picture
    extra = 1
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields': ('ordering',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'status',
            ('title', 'text',),
            ('image', 'link'),
            'cropping',
            'slider',
        )}),
    )
    can_delete = True


class SliderAdmin(ExtendibleModelAdmin):
    prepopulated_fields = {"slug": ("name",)}
    save_on_top = True
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields': ('ordering',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'status', 'name', 'slug',
        )}),
    )
    list_display = (
        'get_status_display', 'ordering', 'name', 'slug', 'get_edit_icon', 'get_delete_icon',
    )
    inlines = [PictureInline]


class PictureAdmin(ImageCroppingMixin, ExtendibleModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields': ('ordering',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'status',
            ('title', 'text',),
            ('image', 'link'),
            'cropping',
            'slider',
        )}),
    )
    list_display = (
        'status', 'ordering', 'title', 'slider', 'get_edit_icon', 'get_delete_icon',
    )

admin.site.register(Slider, SliderAdmin)
admin.site.register(Picture, PictureAdmin)
