# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext as _
from django.conf import settings

from cms.models.pluginmodel import CMSPlugin

from jmb.core.db.cmsmodels import StatusModel

from jmb.slider.models import Slider


###################################
## CMS MODELS                    ##
###################################

class SliderSettings(CMSPlugin, StatusModel):
    template_name = models.CharField(
        _("Template"),
        max_length=100,
        choices=settings.SLIDER_SLIDER_CMSPLUGIN_PRESSLIST_TEMPLATES,
        default="slider/cms_plugins/slider1.html",
    )
    slider = models.ForeignKey(
        'slider.Slider',
        verbose_name=_("Slider"),
        help_text=_("Slider collection to show")
    )
    speed = models.PositiveIntegerField(
        _("Speed"),
        null=True, blank=True,
        help_text=_("(Optional) Speed of the slideshow cycling in ms")
    )
    animation = models.CharField(
        max_length=10,
        choices=settings.SLIDER_SLIDER_CMSPLUGIN_ANIMATION_TYPE,
        default="slide",
        help_text=_("Animation type")
    )

    def __unicode__(self):
        if self.status:
            return "On - %s" % self.slider
        else:
            return "Off - %s" % self.slider

    class Meta:
        verbose_name = _("Slider")
        app_label = "slider"