# -*- coding: utf-8 -*-

import datetime

from django.utils.translation import ugettext_lazy as _
from django.db import connections
from django.db.models import Sum
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.slider.models import Slider
from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': "Slider",
            'display': "tabs",
            'children': (Models(),)
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class SliderDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': "Slider",
            'display': "tabs",
            'children': (Models(),)
        })
        super(SliderDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Main Models"),
            'models': (
                'jmb.slider.models.Slider',
                'jmb.slider.models.Picture',
            ),
        })
        super(Models, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin 
jmb_dashboard.register_group(SliderDashboard, 'jmb.slider')
# Used in /admin/Slider
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.slider')
