# coding: utf-8

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from easy_thumbnails.files import get_thumbnailer
from image_cropping import ImageRatioField

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


class Slider(DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField(
        max_length=200,
        db_index=True,
        verbose_name=_("Name")
    )
    slug = models.SlugField(
        max_length=200,
        db_index=True,
        verbose_name=_("Slug"),
    )

    class Meta:
        verbose_name = _("Slider")
        verbose_name_plural = _("Sliders")
        ordering = ['ordering', 'name']

    def __unicode__(self):
        return self.name


class Picture(DateModel, UserModel, StatusModel, OrderedModel):
    title = models.CharField(
        max_length=200,
        db_index=True,
        blank=True,
        verbose_name=_("Name")
    )
    text = models.TextField(
        verbose_name=_("Text"),
        blank=True
    )
    image = models.ImageField(
        upload_to=settings.SLIDER_PICTURE_FILE_UPLOAD_TO,
        max_length=150,
        verbose_name=_("Image (file)"),
        help_text=_("Images dimensions are 1140x390 pixels")
    )
    cropping = ImageRatioField(
        # used for square images
        'image',
        settings.SLIDER_PICTURE_CROPPING_SIZE,
        verbose_name=_('square cropping')
    )
    link = models.URLField(
        verbose_name=_("Link Associato"),
        max_length=255,
        default=None,
        blank=True,        
    )
    slider = models.ForeignKey(
        Slider,
        related_name=_("pictures"),
        verbose_name=_("Slider")
    )

    class Meta:
        verbose_name = _("Picture")
        verbose_name_plural = _("Pictures")
        ordering = ['ordering', 'title', 'slider']

    def __unicode__(self):
        return self.title

    def get_cropped_picture(self):
        size_list = settings.SLIDER_PICTURE_CROPPING_SIZE.split('x')
        for i in range(0, len(size_list)):
            size_list[i] = int(size_list[i])
        if self.image:
            return get_thumbnailer(
                self.image
            ).get_thumbnail({
                'size': tuple(size_list),
                'box': self.cropping,
                'crop': True,
                'detail': True,
            }).url
        else:
            return ""

if settings.CMS_ENABLED:
    import jmb.slider.cms.models